pub struct SourceParams {
pub path: PathBuf,
pub registry: Registry,
pub verbose: bool,
pub libs: bool,
pub version: Option<Version>,
pub clean: bool,
pub query: Option<String>,
}Expand description
Resolve Rust source code from a crate
Fields
path: PathBufPath to the Cargo workspace or crate to inspect
registry: RegistryRegistry to query when the crate is not present in local metadata
verbose: boolPrint query/package/version/source metadata before the resolved Rust source
libs: boolList library_name -> package_name mappings for a package query
version: Option<Version>Resolve a specific crate version after metadata/cache lookup misses
clean: boolRemove the source cache for the selected registry before resolving
query: Option<String>Rust path to resolve(start always by package_name), for example cf-modkit it will resolve the lib.rs
You can resolve modules tokio::sync to resolve the source code from the sync module from tokio crate
You can also resolve by function name, for example cf-modkit::gts::plugin::BaseModkitPluginV1
Also resolve by function name, for instance cf-modkit::gts::schemas::get_core_gts_schemas
Implementations